#!/usr/bin/env python
# -*- coding: utf-8 -*-

############################################################
#                                                           
# Copyright (C)2018 SenseDeal AI, Inc. All Rights Reserved  
#                                                           
############################################################

'''                                                       
File: .py
Author: xuwei                                        
Email: weix@sensedeal.ai                                 
Last modified: 2018.12.20 18:25 
Description:                                            
'''

import json
import datetime
from sense_data.dictobj import *
from sense_data import stock_pb2
from sense_data.decorator import catch_except_log


def _dict_list_model(list_dict, model_class):
    _dct_list = []
    for _dct in list_dict:
        _dct_list.append(model_class(_dct))
    return _dct_list


class SenseDataService(object):

    def __init__(self):
        pass

    # 1
    @catch_except_log
    def get_stock_price_tick(self, stock_code, stub=None):
        _response = stub.get_stock_price_tick(stock_pb2.Request(stock_code=stock_code))
        _result = json.loads(_response.txt)
        _result = StockPriceTickObj(_result)
        return _result

    # 2
    @catch_except_log
    def get_company_info(self, code, stub=None):
        _stock_code = json.dumps(code)
        _response = stub.get_company_info(stock_pb2.Request(stock_code=_stock_code))
        _list = json.loads(_response.txt)
        if None:
            _obj = CompanyInfoObj(_list[0])
            return _obj
        _dct_list = _dict_list_model(_list, CompanyInfoObj)
        if type(code) == str or len(code) == 1:
            return _dct_list[0]
        else:
            return _dct_list

    # 3
    @catch_except_log
    def get_company_alias(self, code, stub=None):
        _stock_code = json.dumps(code)
        _response = stub.get_company_alias(stock_pb2.Request(stock_code=_stock_code))
        _list = json.loads(_response.txt)
        if None:
            _obj = CompanyAliasObj(_list[0])
            return _obj
        _dct_list = _dict_list_model(_list, CompanyAliasObj)
        return _dct_list

    # 4
    @catch_except_log
    def get_stock_price_day(self, *args, stub=None):
        if len(args) == 3:
            _response = stub.get_stock_price_day(
                stock_pb2.Request(var_num=len(args), stock_code=args[0], start_date=args[1], end_date=args[2]))
        elif len(args) == 2:
            _response = stub.get_stock_price_day(
                stock_pb2.Request(var_num=len(args), stock_code=args[0], start_date=args[1]))
        else:
            _response = stub.get_stock_price_day(
                stock_pb2.Request(var_num=len(args), stock_code=args[0]))

        _list = json.loads(_response.txt)
        if None:
            _obj = StockPriceDayObj(_list[0])
            return _obj
        _dct_list = _dict_list_model(_list, StockPriceDayObj)
        if len(args) == 2:
            return _dct_list[0]
        else:
            return _dct_list

    # 5
    @catch_except_log
    def get_subcompany(self, code, stub=None):
        _stock_code = json.dumps(code)
        _response = stub.get_subcompany(stock_pb2.Request(stock_code=_stock_code))
        _list = json.loads(_response.txt)
        if None:
            _obj = SubcompanyInfoObj(_list[0])
            return _obj
        _dct_list = _dict_list_model(_list, SubcompanyInfoObj)
        return _dct_list

    # 6
    @catch_except_log
    def get_industry_concept(self, code, stub=None):
        _stock_code = json.dumps(code)
        _response = stub.get_industry_concept(stock_pb2.Request(stock_code=_stock_code))
        _list = json.loads(_response.txt)
        if None:
            _obj = IndustryConceptObj(_list[0])
            return _obj
        _dct_list = _dict_list_model(_list, IndustryConceptObj)
        if type(code) == str or len(code) == 1:
            return _dct_list[0]
        else:
            return _dct_list

    # 7
    @catch_except_log
    def get_chairman_supervisor(self, *args, stub=None):
        if len(args) == 2:
            _response = stub.get_chairman_supervisor(
                stock_pb2.Request(var_num=len(args), stock_code=args[0], post=args[1]))
        else:
            _response = stub.get_chairman_supervisor(
                stock_pb2.Request(var_num=len(args), stock_code=args[0]))

        _list = json.loads(_response.txt)
        if None:
            _obj = ChairmanSupervisorObj(_list[0])
            return _obj
        _dct_list = _dict_list_model(_list, ChairmanSupervisorObj)
        return _dct_list

    # 8
    @catch_except_log
    def get_stockholder(self, code, stub=None):
        _response = stub.get_stockholder(stock_pb2.Request(stock_code=code))
        _list = json.loads(_response.txt)
        if None:
            _obj = StockHolderObj(_list[0])
            return _obj
        _dct_list = _dict_list_model(_list, StockHolderObj)
        return _dct_list

    # 9
    @catch_except_log
    def get_trade_date(self, stub=None):
        _date_time_now = datetime.datetime.now()
        _time_str = _date_time_now.strftime("%Y-%m-%d")
        _response = stub.get_trade_date(stock_pb2.Request(time_str=_time_str))
        _time_str = json.loads(_response.txt) + ' 09:30:00'
        _time = datetime.datetime.strptime(_time_str, "%Y-%m-%d %H:%M:%S")
        _result = round(_time.timestamp())
        return _result

    # 10
    @catch_except_log
    def get_market_rise_fall(self, stub=None):
        _response = stub.get_market_rise_fall(stock_pb2.Request())
        _list = json.loads(_response.txt)
        if None:
            _obj = MarketDataObj(_list[0])
            return _obj
        _dct_list = _dict_list_model(_list, MarketDataObj)
        return _dct_list

    # 11
    @catch_except_log
    def get_industry_rise_fall(self, stub=None):
        _response = stub.get_industry_rise_fall(stock_pb2.Request())
        _list = json.loads(_response.txt)
        if None:
            _obj = IndustryDataObj(_list[0])
            return _obj
        _dct_list = _dict_list_model(_list, IndustryDataObj)
        return _dct_list

    # 12
    @catch_except_log
    def get_concept_rise_fall(self, stub=None):
        _response = stub.get_concept_rise_fall(stock_pb2.Request())
        _list = json.loads(_response.txt)
        if None:
            _obj = ConceptDataObj(_list[0])
            return _obj
        _dct_list = _dict_list_model(_list, ConceptDataObj)
        return _dct_list

    # 13
    @catch_except_log
    def get_entity_role(self, entity, stub=None):
        _response = stub.get_entity_role(stock_pb2.Request(entity_name=entity))
        _list = json.loads(_response.txt)
        if None:
            _obj = EntityRoleObj(_list[0])
            return _obj
        _dct_list = _dict_list_model(_list, EntityRoleObj)
        return _dct_list

    # 14
    @catch_except_log
    def get_financial_info(self, code, stub=None):
        _stock_code = json.dumps(code)
        _response = stub.get_financial_info(stock_pb2.Request(stock_code=_stock_code))
        _list = json.loads(_response.txt)
        if None:
            _obj = FinancialInfoObj(_list[0])
            return _obj
        _dct_list = _dict_list_model(_list, FinancialInfoObj)
        if type(code) == str or len(code) == 1:
            return _dct_list[0]
        else:
            return _dct_list

    # 15子龙用
    @catch_except_log
    def get_total_shares(self, code, stub=None):
        _company_code = json.dumps(code)
        _response = stub.get_total_shares(stock_pb2.Request(company_code=_company_code))
        return json.loads(_response.txt)

    # 16子龙用
    @catch_except_log
    def get_company_name(self, stub=None):
        _response = stub.get_company_name(stock_pb2.Request())
        return json.loads(_response.txt)

    # 17广彬用
    @catch_except_log
    def get_title_code(self, title, stub=None):
        _response = stub.get_title_code(stock_pb2.Request(title=title))
        return json.loads(_response.txt)

    # 18子龙用
    @catch_except_log
    def get_actual_control_person(self, code, stub=None):
        _stock_code = json.dumps(code)
        _response = stub.get_actual_control_person(stock_pb2.Request(stock_code=_stock_code))
        _result_list = json.loads(_response.txt)
        if type(code) == str or len(code) == 1:
            return _result_list[0]
        else:
            return _result_list

    # 19徐威用
    @catch_except_log
    def get_code_by_name(self, name, stub=None):
        _response = stub.get_code_by_name(stock_pb2.Request(entity_name=name))
        return json.loads(_response.txt)

    # =19徐威用
    @catch_except_log
    def get_origin_info_by_name(self, name, stub=None):
        _response = stub.get_code_by_name(stock_pb2.Request(entity_name=name))
        return json.loads(_response.txt)

    # 20广彬用
    @catch_except_log
    def get_detail_info_by_name(self, name, stub=None):
        _response = stub.get_detail_info_by_name(stock_pb2.Request(entity_name=name))
        return json.loads(_response.txt)

    # 21广彬用
    @catch_except_log
    def get_company_role_info(self, code, stub=None):
        _response = stub.get_company_role_info(stock_pb2.Request(stock_code=code))
        return json.loads(_response.txt)

    # 22于鑫用
    @catch_except_log
    def get_infos_by_terms(self, names_list: list, stub=None):
        _names_list = json.dumps(names_list, ensure_ascii=False)
        _response = stub.get_infos_by_terms(stock_pb2.Request(entity_name=_names_list))
        return json.loads(_response.txt)

    # 23广彬用
    @catch_except_log
    def get_multi_market_info_by_name(self, name, stub=None):
        _response = stub.get_multi_market_info_by_name(stock_pb2.Request(entity_name=name))
        return json.loads(_response.txt)

    # 24广彬用
    @catch_except_log
    def get_main_market_info_by_name(self, name, stub=None):
        _response = stub.get_main_market_info_by_name(stock_pb2.Request(entity_name=name))
        return json.loads(_response.txt)

    # 25广彬用
    @catch_except_log
    def get_market_info_by_stock_code(self, stock_code, stub=None):
        _response = stub.get_market_info_by_stock_code(stock_pb2.Request(stock_code=stock_code))
        return json.loads(_response.txt)


if __name__ == '__main__':
    import sense_core as sd
    sd.log_init_config(root_path=sd.config('log_path'))
    sense_data = SenseDataService()
    # r = sense_data.get_detail_info_by_name('石化油服')
    r = sense_data.get_stock_price_day('600871', '2019-7-20', '2019-7-22')
    print(r)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

import sense_data.stock_pb2 as stock__pb2


class StockInfStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.get_stock_price_tick = channel.unary_unary(
        '/StockInf/get_stock_price_tick',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_stock_price_day = channel.unary_unary(
        '/StockInf/get_stock_price_day',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_company_info = channel.unary_unary(
        '/StockInf/get_company_info',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_industry_concept = channel.unary_unary(
        '/StockInf/get_industry_concept',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_company_alias = channel.unary_unary(
        '/StockInf/get_company_alias',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_chairman_supervisor = channel.unary_unary(
        '/StockInf/get_chairman_supervisor',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_stockholder = channel.unary_unary(
        '/StockInf/get_stockholder',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_subcompany = channel.unary_unary(
        '/StockInf/get_subcompany',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_trade_date = channel.unary_unary(
        '/StockInf/get_trade_date',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_market_rise_fall = channel.unary_unary(
        '/StockInf/get_market_rise_fall',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_industry_rise_fall = channel.unary_unary(
        '/StockInf/get_industry_rise_fall',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_concept_rise_fall = channel.unary_unary(
        '/StockInf/get_concept_rise_fall',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_entity_role = channel.unary_unary(
        '/StockInf/get_entity_role',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_financial_info = channel.unary_unary(
        '/StockInf/get_financial_info',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_total_shares = channel.unary_unary(
        '/StockInf/get_total_shares',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_company_name = channel.unary_unary(
        '/StockInf/get_company_name',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_title_code = channel.unary_unary(
        '/StockInf/get_title_code',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_actual_control_person = channel.unary_unary(
        '/StockInf/get_actual_control_person',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_code_by_name = channel.unary_unary(
        '/StockInf/get_code_by_name',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_detail_info_by_name = channel.unary_unary(
        '/StockInf/get_detail_info_by_name',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_multi_market_info_by_name = channel.unary_unary(
        '/StockInf/get_multi_market_info_by_name',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_main_market_info_by_name = channel.unary_unary(
        '/StockInf/get_main_market_info_by_name',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_market_info_by_stock_code = channel.unary_unary(
        '/StockInf/get_market_info_by_stock_code',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_company_role_info = channel.unary_unary(
        '/StockInf/get_company_role_info',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )
    self.get_infos_by_terms = channel.unary_unary(
        '/StockInf/get_infos_by_terms',
        request_serializer=stock__pb2.Request.SerializeToString,
        response_deserializer=stock__pb2.Reply.FromString,
        )


class StockInfServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def get_stock_price_tick(self, request, context):
    """输入股票代码返回最新一天股票价格信息
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_stock_price_day(self, request, context):
    """输入股票代码返回历史股价信息
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_company_info(self, request, context):
    """输入股票代码返回基础数据信息
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_industry_concept(self, request, context):
    """输入股票代码返回行业/概念信息
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_company_alias(self, request, context):
    """输入股票代码返回名称
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_chairman_supervisor(self, request, context):
    """输入股票代码返回董监高
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_stockholder(self, request, context):
    """输入股票代码返回股东信息
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_subcompany(self, request, context):
    """输入股票代码返回子公司信息
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_trade_date(self, request, context):
    """输入当前时间戳返回上个收盘日期
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_market_rise_fall(self, request, context):
    """输出市场涨跌幅（中小板、创业板、深市主板和沪市主板）
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_industry_rise_fall(self, request, context):
    """输出行业涨跌幅
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_concept_rise_fall(self, request, context):
    """输出概念涨跌幅
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_entity_role(self, request, context):
    """给实体输出相关上市公司信息及他们的关系
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_financial_info(self, request, context):
    """给股票代码输出前端财务信息
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_total_shares(self, request, context):
    """给公司代码输出total_shares
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_company_name(self, request, context):
    """给公司代码输出total_shares
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_title_code(self, request, context):
    """输入字符串标题匹配返回股票代码or[]
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_actual_control_person(self, request, context):
    """输入股票代码返回实控人名字
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_code_by_name(self, request, context):
    """输入公司名字返回公司code,plate,full_name
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_detail_info_by_name(self, request, context):
    """输入公司名字返回公司redis中的other_name结构
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_multi_market_info_by_name(self, request, context):
    """输入别名返回多市场信息
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_main_market_info_by_name(self, request, context):
    """输入别名返回主市场信息
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_market_info_by_stock_code(self, request, context):
    """输入别名返回主市场信息
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_company_role_info(self, request, context):
    """输入股票代码返回相关人员和公司和该公司的相关关系
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def get_infos_by_terms(self, request, context):
    """输入公司名称列表，返回所有公司代码全称信息
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_StockInfServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'get_stock_price_tick': grpc.unary_unary_rpc_method_handler(
          servicer.get_stock_price_tick,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_stock_price_day': grpc.unary_unary_rpc_method_handler(
          servicer.get_stock_price_day,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_company_info': grpc.unary_unary_rpc_method_handler(
          servicer.get_company_info,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_industry_concept': grpc.unary_unary_rpc_method_handler(
          servicer.get_industry_concept,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_company_alias': grpc.unary_unary_rpc_method_handler(
          servicer.get_company_alias,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_chairman_supervisor': grpc.unary_unary_rpc_method_handler(
          servicer.get_chairman_supervisor,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_stockholder': grpc.unary_unary_rpc_method_handler(
          servicer.get_stockholder,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_subcompany': grpc.unary_unary_rpc_method_handler(
          servicer.get_subcompany,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_trade_date': grpc.unary_unary_rpc_method_handler(
          servicer.get_trade_date,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_market_rise_fall': grpc.unary_unary_rpc_method_handler(
          servicer.get_market_rise_fall,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_industry_rise_fall': grpc.unary_unary_rpc_method_handler(
          servicer.get_industry_rise_fall,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_concept_rise_fall': grpc.unary_unary_rpc_method_handler(
          servicer.get_concept_rise_fall,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_entity_role': grpc.unary_unary_rpc_method_handler(
          servicer.get_entity_role,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_financial_info': grpc.unary_unary_rpc_method_handler(
          servicer.get_financial_info,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_total_shares': grpc.unary_unary_rpc_method_handler(
          servicer.get_total_shares,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_company_name': grpc.unary_unary_rpc_method_handler(
          servicer.get_company_name,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_title_code': grpc.unary_unary_rpc_method_handler(
          servicer.get_title_code,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_actual_control_person': grpc.unary_unary_rpc_method_handler(
          servicer.get_actual_control_person,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_code_by_name': grpc.unary_unary_rpc_method_handler(
          servicer.get_code_by_name,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_detail_info_by_name': grpc.unary_unary_rpc_method_handler(
          servicer.get_detail_info_by_name,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_multi_market_info_by_name': grpc.unary_unary_rpc_method_handler(
          servicer.get_multi_market_info_by_name,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_main_market_info_by_name': grpc.unary_unary_rpc_method_handler(
          servicer.get_main_market_info_by_name,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_market_info_by_stock_code': grpc.unary_unary_rpc_method_handler(
          servicer.get_market_info_by_stock_code,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_company_role_info': grpc.unary_unary_rpc_method_handler(
          servicer.get_company_role_info,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
      'get_infos_by_terms': grpc.unary_unary_rpc_method_handler(
          servicer.get_infos_by_terms,
          request_deserializer=stock__pb2.Request.FromString,
          response_serializer=stock__pb2.Reply.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'StockInf', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: stock.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='stock.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0bstock.proto\"4\n\x06Status\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x0b\n\x03msg\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\"\xae\x01\n\x07Request\x12\x12\n\nstock_code\x18\x01 \x01(\t\x12\x14\n\x0c\x63ompany_code\x18\x02 \x01(\t\x12\x12\n\nstart_date\x18\x03 \x01(\t\x12\x10\n\x08\x65nd_date\x18\x04 \x01(\t\x12\x0c\n\x04post\x18\x05 \x01(\t\x12\x0f\n\x07var_num\x18\x06 \x01(\x05\x12\x10\n\x08time_str\x18\x07 \x01(\t\x12\x13\n\x0b\x65ntity_name\x18\x08 \x01(\t\x12\r\n\x05title\x18\t \x01(\t\"-\n\x05Reply\x12\x0b\n\x03txt\x18\x01 \x01(\t\x12\x17\n\x06status\x18\x02 \x01(\x0b\x32\x07.Status2\xcb\x08\n\x08StockInf\x12*\n\x14get_stock_price_tick\x12\x08.Request\x1a\x06.Reply\"\x00\x12)\n\x13get_stock_price_day\x12\x08.Request\x1a\x06.Reply\"\x00\x12&\n\x10get_company_info\x12\x08.Request\x1a\x06.Reply\"\x00\x12*\n\x14get_industry_concept\x12\x08.Request\x1a\x06.Reply\"\x00\x12\'\n\x11get_company_alias\x12\x08.Request\x1a\x06.Reply\"\x00\x12-\n\x17get_chairman_supervisor\x12\x08.Request\x1a\x06.Reply\"\x00\x12%\n\x0fget_stockholder\x12\x08.Request\x1a\x06.Reply\"\x00\x12$\n\x0eget_subcompany\x12\x08.Request\x1a\x06.Reply\"\x00\x12$\n\x0eget_trade_date\x12\x08.Request\x1a\x06.Reply\"\x00\x12*\n\x14get_market_rise_fall\x12\x08.Request\x1a\x06.Reply\"\x00\x12,\n\x16get_industry_rise_fall\x12\x08.Request\x1a\x06.Reply\"\x00\x12+\n\x15get_concept_rise_fall\x12\x08.Request\x1a\x06.Reply\"\x00\x12%\n\x0fget_entity_role\x12\x08.Request\x1a\x06.Reply\"\x00\x12(\n\x12get_financial_info\x12\x08.Request\x1a\x06.Reply\"\x00\x12&\n\x10get_total_shares\x12\x08.Request\x1a\x06.Reply\"\x00\x12&\n\x10get_company_name\x12\x08.Request\x1a\x06.Reply\"\x00\x12$\n\x0eget_title_code\x12\x08.Request\x1a\x06.Reply\"\x00\x12/\n\x19get_actual_control_person\x12\x08.Request\x1a\x06.Reply\"\x00\x12&\n\x10get_code_by_name\x12\x08.Request\x1a\x06.Reply\"\x00\x12-\n\x17get_detail_info_by_name\x12\x08.Request\x1a\x06.Reply\"\x00\x12\x33\n\x1dget_multi_market_info_by_name\x12\x08.Request\x1a\x06.Reply\"\x00\x12\x32\n\x1cget_main_market_info_by_name\x12\x08.Request\x1a\x06.Reply\"\x00\x12\x33\n\x1dget_market_info_by_stock_code\x12\x08.Request\x1a\x06.Reply\"\x00\x12+\n\x15get_company_role_info\x12\x08.Request\x1a\x06.Reply\"\x00\x12(\n\x12get_infos_by_terms\x12\x08.Request\x1a\x06.Reply\"\x00\x62\x06proto3')
)




_STATUS = _descriptor.Descriptor(
  name='Status',
  full_name='Status',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='code', full_name='Status.code', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg', full_name='Status.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='Status.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15,
  serialized_end=67,
)


_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stock_code', full_name='Request.stock_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='company_code', full_name='Request.company_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date', full_name='Request.start_date', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date', full_name='Request.end_date', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='post', full_name='Request.post', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='var_num', full_name='Request.var_num', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_str', full_name='Request.time_str', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='entity_name', full_name='Request.entity_name', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='title', full_name='Request.title', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=70,
  serialized_end=244,
)


_REPLY = _descriptor.Descriptor(
  name='Reply',
  full_name='Reply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='txt', full_name='Reply.txt', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='Reply.status', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=246,
  serialized_end=291,
)

_REPLY.fields_by_name['status'].message_type = _STATUS
DESCRIPTOR.message_types_by_name['Status'] = _STATUS
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['Reply'] = _REPLY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Status = _reflection.GeneratedProtocolMessageType('Status', (_message.Message,), {
  'DESCRIPTOR' : _STATUS,
  '__module__' : 'stock_pb2'
  # @@protoc_insertion_point(class_scope:Status)
  })
_sym_db.RegisterMessage(Status)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
  'DESCRIPTOR' : _REQUEST,
  '__module__' : 'stock_pb2'
  # @@protoc_insertion_point(class_scope:Request)
  })
_sym_db.RegisterMessage(Request)

Reply = _reflection.GeneratedProtocolMessageType('Reply', (_message.Message,), {
  'DESCRIPTOR' : _REPLY,
  '__module__' : 'stock_pb2'
  # @@protoc_insertion_point(class_scope:Reply)
  })
_sym_db.RegisterMessage(Reply)



_STOCKINF = _descriptor.ServiceDescriptor(
  name='StockInf',
  full_name='StockInf',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=294,
  serialized_end=1393,
  methods=[
  _descriptor.MethodDescriptor(
    name='get_stock_price_tick',
    full_name='StockInf.get_stock_price_tick',
    index=0,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_stock_price_day',
    full_name='StockInf.get_stock_price_day',
    index=1,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_company_info',
    full_name='StockInf.get_company_info',
    index=2,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_industry_concept',
    full_name='StockInf.get_industry_concept',
    index=3,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_company_alias',
    full_name='StockInf.get_company_alias',
    index=4,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_chairman_supervisor',
    full_name='StockInf.get_chairman_supervisor',
    index=5,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_stockholder',
    full_name='StockInf.get_stockholder',
    index=6,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_subcompany',
    full_name='StockInf.get_subcompany',
    index=7,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_trade_date',
    full_name='StockInf.get_trade_date',
    index=8,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_market_rise_fall',
    full_name='StockInf.get_market_rise_fall',
    index=9,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_industry_rise_fall',
    full_name='StockInf.get_industry_rise_fall',
    index=10,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_concept_rise_fall',
    full_name='StockInf.get_concept_rise_fall',
    index=11,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_entity_role',
    full_name='StockInf.get_entity_role',
    index=12,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_financial_info',
    full_name='StockInf.get_financial_info',
    index=13,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_total_shares',
    full_name='StockInf.get_total_shares',
    index=14,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_company_name',
    full_name='StockInf.get_company_name',
    index=15,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_title_code',
    full_name='StockInf.get_title_code',
    index=16,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_actual_control_person',
    full_name='StockInf.get_actual_control_person',
    index=17,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_code_by_name',
    full_name='StockInf.get_code_by_name',
    index=18,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_detail_info_by_name',
    full_name='StockInf.get_detail_info_by_name',
    index=19,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_multi_market_info_by_name',
    full_name='StockInf.get_multi_market_info_by_name',
    index=20,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_main_market_info_by_name',
    full_name='StockInf.get_main_market_info_by_name',
    index=21,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_market_info_by_stock_code',
    full_name='StockInf.get_market_info_by_stock_code',
    index=22,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_company_role_info',
    full_name='StockInf.get_company_role_info',
    index=23,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='get_infos_by_terms',
    full_name='StockInf.get_infos_by_terms',
    index=24,
    containing_service=None,
    input_type=_REQUEST,
    output_type=_REPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_STOCKINF)

DESCRIPTOR.services_by_name['StockInf'] = _STOCKINF

# @@protoc_insertion_point(module_scope)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''                                                          
Copyright (C)2018 SenseDeal AI, Inc. All Rights Reserved                                                      
File: {name}.py
Author: xuwei                                        
Email: weix@sensedeal.ai                                 
Last modified: 2018.12.23
Description:                                            
'''


class StockPriceTickObj(object):
    def __init__(self, dct):
        self.stock_code = dct['stock_code']
        self.name = dct['name']
        self.open_today = dct['open_today']
        self.close_last = dct['close_last']
        self.price_current = dct['price_current']
        self.price_high = dct['price_high']
        self.price_low = dct['price_low']
        self.bid_buy = dct['bid_buy']
        self.bid_sell = dct['bid_sell']
        self.deal_amount = dct['deal_amount']
        self.turnover = dct['turnover']
        self.buy_amount_1 = dct['buy_amount_1']
        self.buy_price_1 = dct['buy_price_1']
        self.buy_amount_2 = dct['buy_amount_2']
        self.buy_price_2 = dct['buy_price_2']
        self.buy_amount_3 = dct['buy_amount_3']
        self.buy_price_3 = dct['buy_price_3']
        self.buy_amount_4 = dct['buy_amount_4']
        self.buy_price_4 = dct['buy_price_4']
        self.buy_amount_5 = dct['buy_amount_5']
        self.buy_price_5 = dct['buy_price_5']
        self.sell_amount_1 = dct['sell_amount_1']
        self.sell_price_1 = dct['sell_price_1']
        self.sell_amount_2 = dct['sell_amount_2']
        self.sell_price_2 = dct['sell_price_2']
        self.sell_amount_3 = dct['sell_amount_3']
        self.sell_price_3 = dct['sell_price_3']
        self.sell_amount_4 = dct['sell_amount_4']
        self.sell_price_4 = dct['sell_price_4']
        self.sell_amount_5 = dct['sell_amount_5']
        self.sell_price_5 = dct['sell_price_5']
        self.trade_date = dct['trade_date']
        self.trade_time = dct['trade_time']


class CompanyInfoObj(object):
    def __init__(self, dct):
        self.stock_code = dct['stock_code']
        self.company_code = dct['company_code']
        self.company_name_full = dct['company_name_full']
        self.company_name = dct['company_name']
        self.region = dct['region']
        self.city = dct['city']
        self.register_address = dct['register_address']
        self.web = dct['web']
        self.profile = dct['profile']
        self.main_products = dct['main_products']
        self.business_scope = dct['business_scope']
        self.legal_represent = dct['legal_represent']
        self.chairman = dct['chairman']
        self.manager = dct['manager']


class StockPriceDayObj(object):
    def __init__(self, dct):
        self.stock_code = dct['stock_code']
        self.company_name = dct['company_name']
        self.time = dct['time']
        self.last_close = dct['last_close']
        self.open = dct['open']
        self.high = dct['high']
        self.low = dct['low']
        self.close = dct['close']
        self.before_open = dct['before_open']
        self.before_high = dct['before_high']
        self.before_low = dct['before_low']
        self.before_close = dct['before_close']
        # self.after_open = dct['after_open']
        # self.after_high = dct['after_high']
        # self.after_low = dct['after_low']
        # self.after_close = dct['after_close']
        self.volume = dct['volume']
        self.turnover = dct['turnover']
        self.change = dct['change']
        self.turn_rate = dct['turn_rate']


class CompanyAliasObj(object):
    def __init__(self, dct):
        # self.stock_code = dct['stock_code']
        self.company_code = dct['company_code']
        self.company_name = dct['company_name']
        self.other_name = dct['other_name']


class SubcompanyInfoObj(object):
    def __init__(self, dct):
        self.stock_code = dct['stock_code']
        self.company_code = dct['company_code']
        self.company_name = dct['company_name']
        self.sub_company_code = dct['sub_company_code']
        self.sub_company_name = dct['sub_company_name']
        self.industry_type = dct['industry_type']


class IndustryConceptObj(object):
    def __init__(self, dct):
        self.stock_code = dct['stock_code']
        self.company_code = dct['company_code']
        self.concept = dct['concept']
        self.industry = dct['industry']
        self.company_name = dct['company_name']


class ChairmanSupervisorObj(object):
    def __init__(self, dct):
        self.person_name = dct['person_name']
        self.post = dct['post']
        self.role = dct['role']
        self.degree = dct['degree']
        self.age = dct['age']


class StockHolderObj(object):
    def __init__(self, dct):
        self.stock_code = dct['stock_code']
        self.company_code = dct['company_code']
        self.shareholder_name = dct['shareholder_name']
        self.stock_num = dct['stock_num']
        self.stock_ratio = dct['stock_ratio']
        self.stock_type = dct['stock_type']
        self.shareholder_nature = dct['shareholder_nature']
        self.rank = dct['rank']


class IndustryDataObj(object):
    def __init__(self, dct):
        self.PUBKEYCODE = dct['PUBKEYCODE']
        self.PUBLISHNAME = dct['PUBLISHNAME']
        self.TRADEDATE = dct['TRADEDATE']
        self.CHG = dct['CHG']


class ConceptDataObj(object):
    def __init__(self, dct):
        self.PUBKEYCODE = dct['PUBKEYCODE']
        self.PUBLISHNAME = dct['PUBLISHNAME']
        self.TRADEDATE = dct['TRADEDATE']
        self.CHG = dct['CHG']


class MarketDataObj(object):
    def __init__(self, dct):
        self.stock_code = dct['stock_code']
        self.trade_date = dct['trade_date']
        self.raise_fall = dct['raise_fall']
        self.name = dct['name']


class EntityRoleObj(object):
    def __init__(self, dct):
        self.stock_code = dct['stock_code']
        self.company_code = dct['company_code']
        self.company_name = dct['company_name']
        self.role_type = dct['role_type']
        self.role_content = dct['role_content']


class FinancialInfoObj(object):
    def __init__(self, dct):
        self.stock_code = dct['stock_code']
        self.company_code = dct['company_code']
        self.debt_ratio = dct['debt_ratio']
        self.cash_flow_ratio = dct['cash_flow_ratio']
        self.goodwill_ratio = dct['goodwill_ratio']
        self.asset_income_ratio = dct['asset_income_ratio']
        self.flow_ratio = dct['flow_ratio']
        self.turnover_ratio = dct['turnover_ratio']
        self.profit_increase_ratio = dct['profit_increase_ratio']
        self.capital_increase_ratio = dct['capital_increase_ratio']
        self.equity_interest_debt_ratio = dct['equity_interest_debt_ratio']
        self.finance_cost_ratio = dct['finance_cost_ratio']
        self.capital_impairment_ratio = dct['capital_impairment_ratio']
        self.pre_account_ratio = dct['pre_account_ratio']
        self.net_assets_ratio = dct['net_assets_ratio']
        self.retain_income_ratio = dct['retain_income_ratio']
        self.debt_change_rate = dct['debt_change_rate']
        self.record_time = dct['record_time']


class TotalSharesObj(object):
    def __init__(self, dct):
        self.company_code = dct['company_code']
        self.total_shares = dct['total_shares']



#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''
Copyright (C)2018 SenseDeal AI, Inc. All Rights Reserved
File: {name}.py
Author: xuwei
Email: weix@sensedeal.ai
Last modified: 2018.12.23
Description:
'''

from multiprocessing import *
from sense_data import *

# 多进程执行函数
def test(i):
    print(get_stock_price_day(i))

#多进程管理函数
def pool_process(functor,list,num):
    pass
    pool = Pool(num)
    pool.map(functor, list) #functor 是计算函数，list是列表
    pool.close()  # 关闭进程池，不再接受新的进程
    pool.join()  # 主进程阻塞等待子进程的退出

# 分配
def loop():
    l = [str(i) for i in range(1000)]
    pool_process(test,l ,4)

if __name__ == '__main__':
    loop()


#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''                                                          
Copyright (C)2018 SenseDeal AI, Inc. All Rights Reserved                                                      
Author: xuwei                                        
Email: weix@sensedeal.ai                                 
Description:                                    
'''


import time
import grpc
import sense_core as sd
from sense_data import stock_pb2_grpc


def catch_except_log(func):
    def try_catch(*args, **kwargs):
        _num = 1
        while True:
            try:
                with grpc.insecure_channel(sd.config('data_rpc', 'host') + ":" + sd.config('data_rpc', 'port'),
                                           options=[('grpc.max_send_message_length', 30 * 1024 * 1024),
                                                    ('grpc.max_receive_message_length', 30 * 1024 * 1024)]) as channel:
                    _stub = stock_pb2_grpc.StockInfStub(channel)
                    r = func(*args, stub=_stub, **kwargs)
                    return r
            except Exception as e:
                #time.sleep(3)
                _num += 1
                if _num > 1:
                    sd.log_exception("%s: %s, args: %s, xargs: %s " %(func.__name__, e, str(args), str(kwargs)))
                    return None
    return try_catch



#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''
Copyright (C)2018 SenseDeal AI, Inc. All Rights _reserved
File: {name}.py
Author: xuwei
Email: weix@sensedeal.ai
Last modified: 2018.12.23
Description:
'''

from sense_data import SenseDataService
import sense_core as sd

sd.log_init_config('settings', sd.config('log_path'))


# 1
def test_get_stock_price_tick():
    print(sd.config('data_rpc', 'host'))
    _xw = SenseDataService()
    _stock_code = '688019'
    _res = _xw.get_stock_price_tick(_stock_code)
    print(_res)
    print(_res.trade_date)
    print(_res.trade_time)
    print(_res.bid_buy)
    print(_res.bid_sell)
    print(_res.close_last)


# 2
def test_get_stock_price_day():
    _xw = SenseDataService()
    _stock_code = '000002'
    _res = _xw.get_stock_price_day(_stock_code, '2019-7-21', '2019-8-3')
    print(_res[0].change)
    print(_res[-1])


# 3
def test_get_subcompany():
    _xw = SenseDataService()
    _stock_code = ['002195']
    _res = _xw.get_subcompany(_stock_code)
    print(_res)
    print(_res[0].company_name)


# 4
def test_get_company_info():
    _xw = SenseDataService()
    _stock_code = ['000045']
    _res = _xw.get_company_info(_stock_code)
    print(_res)
    print(_res.business_scope)


# 5
def test_get_company_alias():
    _xw = SenseDataService()
    _stock_code = ['000045', '000046']
    _res = _xw.get_company_alias(_stock_code)
    print(_res)
    print(_res[0].other_name)


# 6
def test_get_industry_concept():
    _xw = SenseDataService()
    _stock_code = ['000060']
    _res = _xw.get_industry_concept(_stock_code)
    print(_res.industry)
    print(_res.concept)
    # print(_res.company_name)


# 7
def test_get_chairman_supervisor():
    _xw = SenseDataService()
    _stock_code = '000045'
    _res = _xw.get_chairman_supervisor(_stock_code)
    print(_res)
    print(_res[0].person_name)


# 8
def test_get_stockholder():
    _xw = SenseDataService()
    _stock_code = '000045'
    _res = _xw.get_stockholder(_stock_code)
    print(_res[0].shareholder_name)
    # print(_res.company_name)


# 9
def test_get_trade_date():
    _xw = SenseDataService()
    _res = _xw.get_trade_date()
    print(_res)


# 10
def test_get_market_rise_fall():
    _xw = SenseDataService()
    _res = _xw.get_market_rise_fall()
    print(_res)


# 11
def test_get_industry_rise_fall():
    _xw = SenseDataService()
    _res = _xw.get_industry_rise_fall()
    print(_res)


# 12
def test_get_concept_rise_fall():
    _xw = SenseDataService()
    _res = _xw.get_concept_rise_fall()
    print(_res)


# 13
def test_get_entity_role():
    print(sd.config('data_rpc', 'host'))
    _entity_name = '万峰'
    _xw = SenseDataService()
    _res = _xw.get_entity_role(_entity_name)
    print(_res)
    print(_res[0].role_content)


# 14
def test_get_financial_info():
    print(sd.config('data_rpc', 'host'))
    _xw = SenseDataService()
    _stock_code = ['002195']
    _res = _xw.get_financial_info(_stock_code)
    print(_res)
    print(_res.capital_increase_ratio)


# 15
def test_get_total_shares():
    _xw = SenseDataService()
    _stock_code = ['10043749']
    _res = _xw.get_total_shares(_stock_code)
    print(_res)
    print(_res[0])
    print(_res[0]['company_code'])


# 16
def test_get_company_name():
    _xw = SenseDataService()
    _res = _xw.get_company_name()
    print(_res)


# 17广彬用
def test_get_title_code():
    _xw = SenseDataService()
    _title = '沃格光电今天买进新大洲'
    _res = _xw.get_title_code(_title)
    print(_res)


# 18
def test_get_actual_control_person():
    _xw = SenseDataService()
    _stock_code = ['430159']
    _res = _xw.get_actual_control_person(_stock_code)
    print(_res)
    # print(_res.business_scope)


# 19
def test_get_code_by_name():
    _xw = SenseDataService()
    _res = _xw.get_code_by_name('旭辉控股(集团)有限公司')
    print(_res)
    # print(_res.business_scope)


# 20=19
def test_get_origin_info_by_name():
    _xw = SenseDataService()
    _res = _xw.get_origin_info_by_name('南方人民币')
    print(_res)
    # print(_res.business_scope)


# 21-redis形式
def test_get_detail_info_by_name():
    _xw = SenseDataService()
    _res = _xw.get_detail_info_by_name('南方人民币')
    print(_res)
    # print(_res.business_scope)


# 22
def test_get_company_role_info():
    _xw = SenseDataService()
    _res = _xw.get_company_role_info('600053')
    print(_res)
    # print(_res.business_scope)

# 23
def test_get_infos_by_terms():
    _xw = SenseDataService()
    _res = _xw.get_infos_by_terms(['南方人民币'])
    print(_res)
    # print(_res.business_scope)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

'''
Copyright (C)2018 SenseDeal AI, Inc. All Rights Reserved
File: {name}.py
Author: xuwei
Email: weix@sensedeal.ai
Last modified: 2018.12.23
Description:
'''

from setuptools import setup, find_packages

requirements = [
    "grpcio",
    "grpcio-tools",
    "sense-core",
    "datetime",
]

# with open("README.md", "r") as fh:
#     long_description = fh.read().encode("bytes")

setup(
    name='sense-data',
    version='0.5.9',
    packages=['sense_data'],
    #packages=find_packages('client_rpc'),  # 包含所有sense_data中的包
    #package_dir = {'':'client_rpc'},   # 告诉distutils包都在sense_data下
    include_package_data = True,
    install_requires=requirements,


    license='XW License',  # example license
    author='xw20181227',
    author_email='weix@sensedeal.ai',
    description='stock information',
    # long_description=long_description,
    # long_description_content_type="text/markdown",
    #keywords = '',
    #url = '',
)
